/* ATtiny85 as an I2C Master  Ex1          BroHogan                      1/21/11
 * I2C master reading DS1621 temperature sensor. (display with leds)
 * SETUP:
 * ATtiny Pin 1 = (RESET) N/U                      ATtiny Pin 2 = (D3) LED3
 * ATtiny Pin 3 = (D4) to LED1                     ATtiny Pin 4 = GND
 * ATtiny Pin 5 = SDA on DS1621                    ATtiny Pin 6 = (D1) to LED2
 * ATtiny Pin 7 = SCK on DS1621                    ATtiny Pin 8 = VCC (2.7-5.5V)
 * NOTE! - It's very important to use pullups on the SDA & SCL lines!
 * DS1621 wired per data sheet. This ex assumes A0-A2 are set LOW for an addeess of 0x48
 * TinyWireM USAGE & CREDITS: - see TinyWireM.h
 * NOTES:
 * The ATtiny85 + DS1621 draws 1.7mA @5V when leds are not on and not reading temp.
 * Using sleep mode, they draw .2 @5V @ idle - see http://brownsofa.org/blog/archives/261
 */

#include <TinyWireM.h>                  // I2C Master lib for ATTinys which use USI

#define EEPROM_ADDR   0x50              // 7 bit I2C address for EEPROM 24LC512
#define LED1_PIN         4              // ATtiny Pin 3
#define LED2_PIN         1              // ATtiny Pin 6


void setup(){
    pinMode(LED1_PIN,OUTPUT);
    pinMode(LED2_PIN,OUTPUT);
    TinyWireM.begin();                    // initialize I2C lib
    digitalWrite(LED1_PIN, HIGH);         // show it's alive
    digitalWrite(LED2_PIN, HIGH);         // show it's alive
    delay(500);
    clear_eeprom();
    digitalWrite(LED2_PIN, LOW);
    digitalWrite(LED1_PIN, LOW);
    delay(1000);
}


void clear_eeprom() {
unsigned int i;
byte a[10]={1, 0, 0, 1, 1, 1, 0, 1, 0, 1};

    for (i=0; i<10; i++) {
        writeData(EEPROM_ADDR, i, a[i]);
        delay(10);
    }
}


void loop(){
unsigned int i;
byte temp, light;

    digitalWrite(LED1_PIN, HIGH);
    for (i=0; i<10; i++) {
        temp = readData(EEPROM_ADDR, i);
        if (temp == 0) {
            digitalWrite(LED2_PIN, LOW);
        } else {
            digitalWrite(LED2_PIN, HIGH);
        }
        delay(500);
        digitalWrite(LED2_PIN, LOW);
        delay(100);
    }
    digitalWrite(LED1_PIN, LOW);
    delay(500);
}


void writeData(int device, unsigned int add, byte data) {
byte temp;
// writes a byte of data 'data' to the chip at I2C address 'device', in memory location 'add'
    TinyWireM.beginTransmission(device);
    TinyWireM.send((byte)(add >> 8));   // left-part of pointer address
    TinyWireM.send((byte)(add & 0xFF)); // and the right
    TinyWireM.send(data);
    temp = TinyWireM.endTransmission();
    delay(10);
}

byte readData(int device, unsigned int add) {
// reads a byte of data from memory location 'add' in chip at I2C address 'device'
    byte temp, result;  // returned value
    TinyWireM.beginTransmission(device); //  these three lines set the pointer position in the EEPROM
    TinyWireM.send((byte)(add >> 8));   // left-part of pointer address
    TinyWireM.send((byte)(add & 0xFF)); // and the right
    TinyWireM.endTransmission();
    TinyWireM.requestFrom(device, 1); // now get the byte of data...
    result = TinyWireM.receive();  
    return result; // and return it as a result of the function readData
}
